<?php
/**
 * Theme information crater
 *
 * @package crater-free
 */


if ( ! class_exists( 'CraterFree_About_Page' ) ) {
	/**
	 * Singleton class used for generating the about page of the theme.
	 */
	class CraterFree_About_Page {
		/**
		 * Define the version of the class.
		 *
		 * @var string $version The CraterFree_About_Page class version.
		 */
		private $version = '1.0.0';
		/**
		 * Used for loading the texts and setup the actions inside the page.
		 *
		 * @var array $config The configuration array for the theme used.
		 */
		private $config;
		/**
		 * Get the theme name using wp_get_theme.
		 *
		 * @var string $theme_name The theme name.
		 */
		private $theme_name;
		/**
		 * Get the theme slug ( theme folder name ).
		 *
		 * @var string $theme_slug The theme slug.
		 */
		private $theme_slug;
		/**
		 * The current theme object.
		 *
		 * @var WP_Theme $theme The current theme.
		 */
		private $theme;
		/**
		 * Holds the theme version.
		 *
		 * @var string $theme_version The theme version.
		 */
		private $theme_version;		
		/**
		 * Define the html notification content displayed upon activation.
		 *
		 * @var string $notification The html notification content.
		 */
		private $notification;
		/**
		 * The single instance of CraterFree_About_Page
		 *
		 * @var CraterFree_About_Page $instance The CraterFree_About_Page instance.
		 */
		private static $instance;
		/**
		 * The Main CraterFree_About_Page instance.
		 *
		 * We make sure that only one instance of CraterFree_About_Page exists in the memory at one time.
		 *
		 * @param array $config The configuration array.
		 */
		public static function crater_free_init( $config ) {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof CraterFree_About_Page ) ) {
				self::$instance = new CraterFree_About_Page;				
				self::$instance->config = $config;
				self::$instance->crater_free_setup_config();
				self::$instance->crater_free_setup_actions();				
			}
		}

		/**
		 * Setup the class props based on the config array.
		 */
		public function crater_free_setup_config() {
			$theme = wp_get_theme();
			if ( is_child_theme() ) {
				$this->theme_name = $theme->parent()->get( 'Name' );
				$this->theme      = $theme->parent();
			} else {
				$this->theme_name = $theme->get( 'Name' );
				$this->theme      = $theme->parent();
			}
			$this->theme_version = $theme->get( 'Version' );
			$this->theme_slug    = $theme->get_template();			
			$this->notification  = isset( $this->config['notification'] ) ? $this->config['notification'] : ( '<p>' . sprintf( 'Welcome! Thank you for choosing %1$s ! To take full advantage of this theme, please make sure you visit our %2$swelcome page%3$s.', $this->theme_name, '<a href="' . esc_url( admin_url( 'themes.php?page=' . $this->theme_slug . '-theme-info' ) ) . '">', '</a>' ) . '</p><p><a href="' . esc_url( admin_url( 'themes.php?page=' . $this->theme_slug . '-theme-info' ) ) . '" class="button" style="text-decoration: none;">' . sprintf( 'Get started with %s', $this->theme_name ) . '</a></p>' );		
		}

		/**
		 * Setup the actions used for this page.
		 */
		public function crater_free_setup_actions() {
			
			/* activation notice */
			add_action( 'load-themes.php', array( $this, 'crater_free_activation_admin_notice' ) );						
		}		
		

		/**
		 * Adds an admin notice upon successful activation.
		 */
		public function crater_free_activation_admin_notice() {
			global $pagenow;
			if ( is_admin() && ( 'themes.php' == $pagenow ) && isset( $_GET['activated'] ) ) {
				add_action( 'admin_notices', array( $this, 'crater_free_about_page_welcome_admin_notice' ), 99 );
			}
		}

		/**
		 * Display an admin notice linking to the about page
		 */
		public function crater_free_about_page_welcome_admin_notice() {
			if ( ! empty( $this->notification ) ) {
				echo '<div class="updated notice is-dismissible">';
				echo wp_kses_post( $this->notification );
				echo '</div>';
			}
		}		

	}
}


/**
 *  Adding a About crater page 
 */
add_action('admin_menu', 'crater_free_add_menu');

function crater_free_add_menu() {
     add_theme_page(__('About Crater Free Theme','crater-free'), __('About Free Crater Theme','crater-free'),'manage_options', __('crater-free-theme-info','crater-free'), __('crater_free_theme_info','crater-free'));
}

/**
 *  Callback
 */
function crater_free_theme_info() {
?>
	<div class="crater-info">
		<div class="container">
			<div class="row">
				<div class="col-md-12">
					<div class="title">
						<h2><?php _e( 'Thank you for using Crater Free WordPress theme', 'crater-free' ); ?></h2>
						<div class="title-content">
							<p><?php _e( 'Crater Free is a free business WordPress theme suitable for almost any website. You can build a business, travel, food and restaurants, construction, agency, real estate, hotels, wedding, photography websites from this theme. Crater Free theme is responsive and can be viewed in any mobile and tablet devices. This theme has variety of options to offer and has great page speed. Crater Free can be customized via Theme Customizer and Elementor page builder. To get the preview of this theme, please click on the View Demo link.', 'crater-free' ); ?></p>
						</div>
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-md-3">
					<div class="section-box section-last">
						<div class="icon">
							<span class="dashicons dashicons-cart"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_PRO_URL); ?>" target="_blank"><?php _e( 'BUY PRO WITH<br/> EXTRA FEATURES', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-visibility"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_URL); ?>" target="_blank"><?php _e( 'VIEW<br/> DEMO', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-format-aside"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_DOC_URL); ?>" target="_blank"><?php _e( 'VIEW<br/> DOCUMENTATION', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-video-alt2"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_VIDEOS_URL); ?>" target="_blank"><?php _e( 'VIDEO<br/> TUTORIALS', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
			</div>

			<div class="row">
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-sos"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_SUPPORT_URL); ?>" target="_blank"><?php _e( 'ASK FOR<br/> SUPPORT', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-star-filled"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_RATINGS_URL); ?>" target="_blank"><?php _e( 'RATE OUR<br/> THEME', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-admin-tools"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_CHANGELOGS_URL); ?>" target="_blank"><?php _e( 'VIEW<br/> CHANGELOGS', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
				<div class="col-md-3">
					<div class="section-box">
						<div class="icon">
							<span class="dashicons dashicons-email-alt"></span>
						</div>
						<div class="heading">
							<h3><a href="<?php echo esc_url(CRATER_FREE_THEME_CONTACT_URL); ?>" target="_blank"><?php _e( 'CONTACT<br/> US', 'crater-free' ); ?></a></h3>
						</div>						
					</div>
				</div>
			</div>
		</div>		
	</div>
<?php
}
